@@ -13,6 +13,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+if defined?(Encoding) && Encoding.default_external.name == 'US-ASCII'
+  Encoding.default_external = 'UTF-8'
+end
+
 module Gem2Deb
 
   class CommandFailed < Exception
