@@ -27,4 +27,16 @@ class Gem2DebTest < Gem2DebTestCase
     assert_match /E: ruby-simplegem: helper-templates-in-copyright/, `lintian #{changes_file}`
   end
 
+  should 'not compress *.rb files installed as examples' do
+    examples_package = File.join(GEM2DEB_ROOT_SOURCE_DIR, 'test/sample/examples')
+    tmpdir = Dir.mktmpdir
+    FileUtils.cp_r(examples_package, tmpdir)
+    Dir.chdir(File.join(tmpdir, 'examples')) do
+      run_command('dpkg-buildpackage -d -us -uc')
+      assert_no_file_exists 'debian/ruby-examples/usr/share/doc/ruby-examples/examples/test.rb.gz'
+      assert_file_exists 'debian/ruby-examples/usr/share/doc/ruby-examples/examples/test.rb'
+    end
+    FileUtils.rm_rf(tmpdir)
+  end
+
 end
